package com.proliferay.demo;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.sql.Blob;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.ProcessAction;
import javax.portlet.ResourceRequest;
import javax.portlet.ResourceResponse;

import com.liferay.counter.service.CounterLocalServiceUtil;
import com.liferay.portal.kernel.dao.jdbc.OutputBlob;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.upload.UploadRequest;
import com.liferay.portal.kernel.util.MimeTypesUtil;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.util.PortalUtil;
import com.liferay.util.bridges.mvc.MVCPortlet;
import com.proliferay.servicebuilder.model.BlobDemo;
import com.proliferay.servicebuilder.service.BlobDemoLocalServiceUtil;

/**
 * 
 * @author Hamidul Islam
 * 
 */

public class BlobDemoPortlet extends MVCPortlet {

	@ProcessAction(name = "upload")
	public void upload(ActionRequest actionRequest,
			ActionResponse actionResponse) throws SystemException,
			FileNotFoundException {

		/**
		 * PortalUtil.getUploadPortletRequest used for getting upload request
		 * 
		 * From the uploaded file get input stream
		 */
		UploadRequest uploadRequest = PortalUtil.getUploadPortletRequest(actionRequest);
		
		
		/**
		 * Get the uploaded file name with extension
		 */
		
		String uploadedFileName = uploadRequest.getFileName("file");
		
		File file = uploadRequest.getFile("file");
		
		InputStream inputStream = new FileInputStream(file);
		/**
		 * Below is the actual blob data
		 */
		OutputBlob blobData = new OutputBlob(inputStream, file.length());

		/**
		 * Create and set the primary key
		 */
		long id = CounterLocalServiceUtil.increment(BlobDemo.class.getName());
		BlobDemo blobDemo = BlobDemoLocalServiceUtil.createBlobDemo(id);

		blobDemo.setName(uploadedFileName);
		blobDemo.setBlobData(blobData);
		blobDemo.setMimeType(MimeTypesUtil.getContentType(file));
		BlobDemoLocalServiceUtil.addBlobDemo(blobDemo);
	}

	/**
	 * This process action is for deleting record in the database
	 */
	@ProcessAction(name = "delete")
	public void delete(ActionRequest actionRequest,
			ActionResponse actionResponse) throws PortalException,
			SystemException {
		long dataId = ParamUtil.getLong(actionRequest, "dataId");
		BlobDemoLocalServiceUtil.deleteBlobDemo(dataId);
	}

	/**
	 * Here serveResource method is used for displaying blob data
	 */
	@Override
	public void serveResource(ResourceRequest resourceRequest,
			ResourceResponse resourceResponse) throws IOException,
			PortletException {

		try {
			long dataId = ParamUtil.getLong(resourceRequest, "dataId");
			BlobDemo blobDemo = BlobDemoLocalServiceUtil.getBlobDemo(dataId);
			if (blobDemo != null) {
				Blob blob = blobDemo.getBlobData();
				byte[] binaryData = blob.getBytes(1, (int) blob.length());
				// resourceResponse.setContentType(blobDemo.getMimeType());

				resourceResponse.setContentType("application/application-download");
				resourceResponse.setProperty("Content-disposition","attachement; filename=" + blobDemo.getName());
				OutputStream o = resourceResponse.getPortletOutputStream();
				o.write(binaryData);
				o.flush();
				o.close();
				resourceResponse.flushBuffer();
			}

		} catch (Exception e) {

		}
	}
}
