/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.proliferay.servicebuilder.service.base;

import com.liferay.portal.kernel.bean.BeanReference;
import com.liferay.portal.kernel.bean.IdentifiableBean;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdate;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdateFactoryUtil;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.DynamicQueryFactoryUtil;
import com.liferay.portal.kernel.dao.orm.Projection;
import com.liferay.portal.kernel.dao.orm.Session;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.search.Indexable;
import com.liferay.portal.kernel.search.IndexableType;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.model.PersistedModel;
import com.liferay.portal.service.BaseLocalServiceImpl;
import com.liferay.portal.service.PersistedModelLocalServiceRegistryUtil;
import com.liferay.portal.service.persistence.UserPersistence;

import com.proliferay.servicebuilder.model.BlobDemo;
import com.proliferay.servicebuilder.model.BlobDemoBlobDataBlobModel;
import com.proliferay.servicebuilder.service.BlobDemoLocalService;
import com.proliferay.servicebuilder.service.persistence.BlobDemoPersistence;

import java.io.Serializable;

import java.util.List;

import javax.sql.DataSource;

/**
 * Provides the base implementation for the blob demo local service.
 *
 * <p>
 * This implementation exists only as a container for the default service methods generated by ServiceBuilder. All custom service methods should be put in {@link com.proliferay.servicebuilder.service.impl.BlobDemoLocalServiceImpl}.
 * </p>
 *
 * @author Hamidul Islam
 * @see com.proliferay.servicebuilder.service.impl.BlobDemoLocalServiceImpl
 * @see com.proliferay.servicebuilder.service.BlobDemoLocalServiceUtil
 * @generated
 */
public abstract class BlobDemoLocalServiceBaseImpl extends BaseLocalServiceImpl
	implements BlobDemoLocalService, IdentifiableBean {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this class directly. Always use {@link com.proliferay.servicebuilder.service.BlobDemoLocalServiceUtil} to access the blob demo local service.
	 */

	/**
	 * Adds the blob demo to the database. Also notifies the appropriate model listeners.
	 *
	 * @param blobDemo the blob demo
	 * @return the blob demo that was added
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.REINDEX)
	@Override
	public BlobDemo addBlobDemo(BlobDemo blobDemo) throws SystemException {
		blobDemo.setNew(true);

		return blobDemoPersistence.update(blobDemo);
	}

	/**
	 * Creates a new blob demo with the primary key. Does not add the blob demo to the database.
	 *
	 * @param blobId the primary key for the new blob demo
	 * @return the new blob demo
	 */
	@Override
	public BlobDemo createBlobDemo(long blobId) {
		return blobDemoPersistence.create(blobId);
	}

	/**
	 * Deletes the blob demo with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param blobId the primary key of the blob demo
	 * @return the blob demo that was removed
	 * @throws PortalException if a blob demo with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.DELETE)
	@Override
	public BlobDemo deleteBlobDemo(long blobId)
		throws PortalException, SystemException {
		return blobDemoPersistence.remove(blobId);
	}

	/**
	 * Deletes the blob demo from the database. Also notifies the appropriate model listeners.
	 *
	 * @param blobDemo the blob demo
	 * @return the blob demo that was removed
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.DELETE)
	@Override
	public BlobDemo deleteBlobDemo(BlobDemo blobDemo) throws SystemException {
		return blobDemoPersistence.remove(blobDemo);
	}

	@Override
	public DynamicQuery dynamicQuery() {
		Class<?> clazz = getClass();

		return DynamicQueryFactoryUtil.forClass(BlobDemo.class,
			clazz.getClassLoader());
	}

	/**
	 * Performs a dynamic query on the database and returns the matching rows.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery)
		throws SystemException {
		return blobDemoPersistence.findWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Performs a dynamic query on the database and returns a range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link com.proliferay.servicebuilder.model.impl.BlobDemoModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @return the range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end)
		throws SystemException {
		return blobDemoPersistence.findWithDynamicQuery(dynamicQuery, start, end);
	}

	/**
	 * Performs a dynamic query on the database and returns an ordered range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link com.proliferay.servicebuilder.model.impl.BlobDemoModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	 * @return the ordered range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end,
		OrderByComparator orderByComparator) throws SystemException {
		return blobDemoPersistence.findWithDynamicQuery(dynamicQuery, start,
			end, orderByComparator);
	}

	/**
	 * Returns the number of rows that match the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the number of rows that match the dynamic query
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public long dynamicQueryCount(DynamicQuery dynamicQuery)
		throws SystemException {
		return blobDemoPersistence.countWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Returns the number of rows that match the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @param projection the projection to apply to the query
	 * @return the number of rows that match the dynamic query
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public long dynamicQueryCount(DynamicQuery dynamicQuery,
		Projection projection) throws SystemException {
		return blobDemoPersistence.countWithDynamicQuery(dynamicQuery,
			projection);
	}

	@Override
	public BlobDemo fetchBlobDemo(long blobId) throws SystemException {
		return blobDemoPersistence.fetchByPrimaryKey(blobId);
	}

	/**
	 * Returns the blob demo with the primary key.
	 *
	 * @param blobId the primary key of the blob demo
	 * @return the blob demo
	 * @throws PortalException if a blob demo with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public BlobDemo getBlobDemo(long blobId)
		throws PortalException, SystemException {
		return blobDemoPersistence.findByPrimaryKey(blobId);
	}

	@Override
	public PersistedModel getPersistedModel(Serializable primaryKeyObj)
		throws PortalException, SystemException {
		return blobDemoPersistence.findByPrimaryKey(primaryKeyObj);
	}

	/**
	 * Returns a range of all the blob demos.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link com.proliferay.servicebuilder.model.impl.BlobDemoModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param start the lower bound of the range of blob demos
	 * @param end the upper bound of the range of blob demos (not inclusive)
	 * @return the range of blob demos
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public List<BlobDemo> getBlobDemos(int start, int end)
		throws SystemException {
		return blobDemoPersistence.findAll(start, end);
	}

	/**
	 * Returns the number of blob demos.
	 *
	 * @return the number of blob demos
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public int getBlobDemosCount() throws SystemException {
		return blobDemoPersistence.countAll();
	}

	/**
	 * Updates the blob demo in the database or adds it if it does not yet exist. Also notifies the appropriate model listeners.
	 *
	 * @param blobDemo the blob demo
	 * @return the blob demo that was updated
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.REINDEX)
	@Override
	public BlobDemo updateBlobDemo(BlobDemo blobDemo) throws SystemException {
		return blobDemoPersistence.update(blobDemo);
	}

	@Override
	public BlobDemoBlobDataBlobModel getBlobDataBlobModel(
		Serializable primaryKey) throws SystemException {
		Session session = null;

		try {
			session = blobDemoPersistence.openSession();

			return (com.proliferay.servicebuilder.model.BlobDemoBlobDataBlobModel)session.get(BlobDemoBlobDataBlobModel.class,
				primaryKey);
		}
		catch (Exception e) {
			throw blobDemoPersistence.processException(e);
		}
		finally {
			blobDemoPersistence.closeSession(session);
		}
	}

	/**
	 * Returns the blob demo local service.
	 *
	 * @return the blob demo local service
	 */
	public com.proliferay.servicebuilder.service.BlobDemoLocalService getBlobDemoLocalService() {
		return blobDemoLocalService;
	}

	/**
	 * Sets the blob demo local service.
	 *
	 * @param blobDemoLocalService the blob demo local service
	 */
	public void setBlobDemoLocalService(
		com.proliferay.servicebuilder.service.BlobDemoLocalService blobDemoLocalService) {
		this.blobDemoLocalService = blobDemoLocalService;
	}

	/**
	 * Returns the blob demo remote service.
	 *
	 * @return the blob demo remote service
	 */
	public com.proliferay.servicebuilder.service.BlobDemoService getBlobDemoService() {
		return blobDemoService;
	}

	/**
	 * Sets the blob demo remote service.
	 *
	 * @param blobDemoService the blob demo remote service
	 */
	public void setBlobDemoService(
		com.proliferay.servicebuilder.service.BlobDemoService blobDemoService) {
		this.blobDemoService = blobDemoService;
	}

	/**
	 * Returns the blob demo persistence.
	 *
	 * @return the blob demo persistence
	 */
	public BlobDemoPersistence getBlobDemoPersistence() {
		return blobDemoPersistence;
	}

	/**
	 * Sets the blob demo persistence.
	 *
	 * @param blobDemoPersistence the blob demo persistence
	 */
	public void setBlobDemoPersistence(BlobDemoPersistence blobDemoPersistence) {
		this.blobDemoPersistence = blobDemoPersistence;
	}

	/**
	 * Returns the counter local service.
	 *
	 * @return the counter local service
	 */
	public com.liferay.counter.service.CounterLocalService getCounterLocalService() {
		return counterLocalService;
	}

	/**
	 * Sets the counter local service.
	 *
	 * @param counterLocalService the counter local service
	 */
	public void setCounterLocalService(
		com.liferay.counter.service.CounterLocalService counterLocalService) {
		this.counterLocalService = counterLocalService;
	}

	/**
	 * Returns the resource local service.
	 *
	 * @return the resource local service
	 */
	public com.liferay.portal.service.ResourceLocalService getResourceLocalService() {
		return resourceLocalService;
	}

	/**
	 * Sets the resource local service.
	 *
	 * @param resourceLocalService the resource local service
	 */
	public void setResourceLocalService(
		com.liferay.portal.service.ResourceLocalService resourceLocalService) {
		this.resourceLocalService = resourceLocalService;
	}

	/**
	 * Returns the user local service.
	 *
	 * @return the user local service
	 */
	public com.liferay.portal.service.UserLocalService getUserLocalService() {
		return userLocalService;
	}

	/**
	 * Sets the user local service.
	 *
	 * @param userLocalService the user local service
	 */
	public void setUserLocalService(
		com.liferay.portal.service.UserLocalService userLocalService) {
		this.userLocalService = userLocalService;
	}

	/**
	 * Returns the user remote service.
	 *
	 * @return the user remote service
	 */
	public com.liferay.portal.service.UserService getUserService() {
		return userService;
	}

	/**
	 * Sets the user remote service.
	 *
	 * @param userService the user remote service
	 */
	public void setUserService(
		com.liferay.portal.service.UserService userService) {
		this.userService = userService;
	}

	/**
	 * Returns the user persistence.
	 *
	 * @return the user persistence
	 */
	public UserPersistence getUserPersistence() {
		return userPersistence;
	}

	/**
	 * Sets the user persistence.
	 *
	 * @param userPersistence the user persistence
	 */
	public void setUserPersistence(UserPersistence userPersistence) {
		this.userPersistence = userPersistence;
	}

	public void afterPropertiesSet() {
		Class<?> clazz = getClass();

		_classLoader = clazz.getClassLoader();

		PersistedModelLocalServiceRegistryUtil.register("com.proliferay.servicebuilder.model.BlobDemo",
			blobDemoLocalService);
	}

	public void destroy() {
		PersistedModelLocalServiceRegistryUtil.unregister(
			"com.proliferay.servicebuilder.model.BlobDemo");
	}

	/**
	 * Returns the Spring bean ID for this bean.
	 *
	 * @return the Spring bean ID for this bean
	 */
	@Override
	public String getBeanIdentifier() {
		return _beanIdentifier;
	}

	/**
	 * Sets the Spring bean ID for this bean.
	 *
	 * @param beanIdentifier the Spring bean ID for this bean
	 */
	@Override
	public void setBeanIdentifier(String beanIdentifier) {
		_beanIdentifier = beanIdentifier;
	}

	@Override
	public Object invokeMethod(String name, String[] parameterTypes,
		Object[] arguments) throws Throwable {
		Thread currentThread = Thread.currentThread();

		ClassLoader contextClassLoader = currentThread.getContextClassLoader();

		if (contextClassLoader != _classLoader) {
			currentThread.setContextClassLoader(_classLoader);
		}

		try {
			return _clpInvoker.invokeMethod(name, parameterTypes, arguments);
		}
		finally {
			if (contextClassLoader != _classLoader) {
				currentThread.setContextClassLoader(contextClassLoader);
			}
		}
	}

	protected Class<?> getModelClass() {
		return BlobDemo.class;
	}

	protected String getModelClassName() {
		return BlobDemo.class.getName();
	}

	/**
	 * Performs an SQL query.
	 *
	 * @param sql the sql query
	 */
	protected void runSQL(String sql) throws SystemException {
		try {
			DataSource dataSource = blobDemoPersistence.getDataSource();

			SqlUpdate sqlUpdate = SqlUpdateFactoryUtil.getSqlUpdate(dataSource,
					sql, new int[0]);

			sqlUpdate.update();
		}
		catch (Exception e) {
			throw new SystemException(e);
		}
	}

	@BeanReference(type = com.proliferay.servicebuilder.service.BlobDemoLocalService.class)
	protected com.proliferay.servicebuilder.service.BlobDemoLocalService blobDemoLocalService;
	@BeanReference(type = com.proliferay.servicebuilder.service.BlobDemoService.class)
	protected com.proliferay.servicebuilder.service.BlobDemoService blobDemoService;
	@BeanReference(type = BlobDemoPersistence.class)
	protected BlobDemoPersistence blobDemoPersistence;
	@BeanReference(type = com.liferay.counter.service.CounterLocalService.class)
	protected com.liferay.counter.service.CounterLocalService counterLocalService;
	@BeanReference(type = com.liferay.portal.service.ResourceLocalService.class)
	protected com.liferay.portal.service.ResourceLocalService resourceLocalService;
	@BeanReference(type = com.liferay.portal.service.UserLocalService.class)
	protected com.liferay.portal.service.UserLocalService userLocalService;
	@BeanReference(type = com.liferay.portal.service.UserService.class)
	protected com.liferay.portal.service.UserService userService;
	@BeanReference(type = UserPersistence.class)
	protected UserPersistence userPersistence;
	private String _beanIdentifier;
	private ClassLoader _classLoader;
	private BlobDemoLocalServiceClpInvoker _clpInvoker = new BlobDemoLocalServiceClpInvoker();
}